# SPDX-FileCopyrightText: 2016-2024 Blender Foundation
#
# SPDX-License-Identifier: GPL-3.0-or-later

from bpy.types import Menu
from .hotkeys import register_hotkey


class PIE_MT_object_selection(Menu):
    bl_idname = "PIE_MT_object_selection"
    bl_label = "Object Select"

    def draw(self, context):
        layout = self.layout
        pie = layout.menu_pie()
        # 4 - LEFT
        pie.operator("object.select_grouped", text="Select Grouped")
        # 6 - RIGHT
        pie.operator("object.select_by_type", text="Select By Type")
        # 2 - BOTTOM
        pie.operator(
            "object.select_all", text="Invert Selection", icon='ZOOM_PREVIOUS'
        ).action = 'INVERT'
        # 8 - TOP
        pie.operator(
            "object.select_all", text="Select All Toggle", icon='NONE'
        ).action = 'TOGGLE'
        # 7 - TOP - LEFT
        pie.operator("view3d.select_circle", text="Circle Select")
        # 9 - TOP - RIGHT
        pie.operator("view3d.select_box", text="Box Select")
        # 1 - BOTTOM - LEFT
        pie.operator("object.select_camera", text="Select Camera")
        # 3 - BOTTOM - RIGHT
        pie.menu("PIE_MT_object_selection_more", text="Select Menu")


class PIE_MT_mesh_selection(Menu):
    bl_idname = "PIE_MT_mesh_selection"
    bl_label = "Mesh Select"

    def draw(self, context):
        layout = self.layout
        pie = layout.menu_pie()
        # 4 - LEFT
        pie.operator("mesh.select_less", text="Select Less")
        # 6 - RIGHT
        pie.operator("mesh.select_more", text="Select More")
        # 2 - BOTTOM
        pie.menu("VIEW3D_MT_edit_mesh_select_loops")
        # 8 - TOP
        pie.operator("mesh.select_all", text="Select All Toggle").action = 'TOGGLE'
        # 7 - TOP - LEFT
        pie.operator("view3d.select_circle", text="Circle Select")
        # 9 - TOP - RIGHT
        pie.operator("view3d.select_box", text="Box Select")
        # 1 - BOTTOM - LEFT
        pie.operator("mesh.select_all", text="Invert Selection").action = 'INVERT'
        # 3 - BOTTOM - RIGHT
        pie.menu("PIE_MT_mesh_selection_mode", text="Edit Modes", icon='VERTEXSEL')


class PIE_MT_object_selection_more(Menu):
    bl_idname = "PIE_MT_object_selection_more"
    bl_label = "More Object Select"

    def draw(self, context):
        layout = self.layout
        pie = layout.menu_pie()
        box = pie.split().column()
        box.operator("object.select_random", text="Select Random")
        box.operator("object.select_linked", text="Select Linked")
        box.separator()

        box.operator("object.select_more", text="More")
        box.operator("object.select_less", text="Less")
        box.separator()

        props = box.operator("object.select_hierarchy", text="Parent")
        props.extend = False
        props.direction = 'PARENT'

        props = box.operator("object.select_hierarchy", text="Child")
        props.extend = False
        props.direction = 'CHILD'
        box.separator()

        props = box.operator("object.select_hierarchy", text="Extend Parent")
        props.extend = True
        props.direction = 'PARENT'

        props = box.operator("object.select_hierarchy", text="Extend Child")
        props.extend = True
        props.direction = 'CHILD'


class PIE_MT_mesh_selection_mode(Menu):
    bl_idname = "PIE_MT_mesh_selection_mode"
    bl_label = "Mesh Selection Mode"

    def draw(self, context):
        layout = self.layout
        pie = layout.menu_pie()
        box = pie.split().column()

        box.operator("mesh.select_mode", text="Vertex", icon='VERTEXSEL').type = 'VERT'
        box.operator("mesh.select_mode", text="Edge", icon='EDGESEL').type = 'EDGE'
        box.operator("mesh.select_mode", text="Face", icon='FACESEL').type = 'FACE'


registry = [
    PIE_MT_object_selection,
    PIE_MT_mesh_selection,
    PIE_MT_object_selection_more,
    PIE_MT_mesh_selection_mode,
]


def register():
    register_hotkey(
        'wm.call_menu_pie',
        op_kwargs={'name': 'PIE_MT_object_selection'},
        hotkey_kwargs={'type': "A", 'value': "PRESS"},
        key_cat="Object Mode",
    )
    register_hotkey(
        'wm.call_menu_pie',
        op_kwargs={'name': 'PIE_MT_mesh_selection'},
        hotkey_kwargs={'type': "A", 'value': "PRESS"},
        key_cat="Mesh",
    )
