# SPDX-FileCopyrightText: 2016-2024 Blender Foundation
#
# SPDX-License-Identifier: GPL-3.0-or-later

import bpy
from .hotkeys import register_hotkey


def delayed_register():
    # This is called from a Timer because bpy.context must be initialized.
    context = bpy.context
    keyconfig = context.window_manager.keyconfigs.active
    if not keyconfig:
        return

    prefs = keyconfig.preferences
    if prefs and hasattr(prefs, 'spacebar_action'):
        # This is a rough way to check if user is on the default "Blender"
        # keymap preset, so they actually have preferences.
        # In this case, we don't need to give them the built-in pie menus,
        # they can configure it themselves thorugh said preferences.
        return

    # Otherwise, they're at our mercy.

    # Mode pie has to go on Ctrl+Tab because Tab is taken by Search,
    # in the Industry Compatible keymap.
    register_hotkey(
        'wm.call_menu_pie',
        op_kwargs={'name': 'VIEW3D_MT_object_mode_pie'},
        hotkey_kwargs={'type': 'TAB', 'value': 'PRESS', 'ctrl': True},
        key_cat='3D View',
    )
    register_hotkey(
        'wm.call_menu_pie',
        op_kwargs={'name': 'VIEW3D_MT_shading_ex_pie'},
        hotkey_kwargs={'type': 'Z', 'value': 'PRESS'},
        key_cat='3D View',
    )

    # Overload the Tilde key so that if tapped, it toggles Orthographic.
    # This is the behaviour from the "Pie Menu on Drag" checkbox in normal
    # keyconfig preferences. But unlike the other two behaviours, this actually adds value,
    # since Persp/Ortho toggle is not in the pie menu itself, because there's no space for it.
    register_hotkey(
        'wm.call_menu_pie_drag_only',
        op_kwargs={
            'name': 'VIEW3D_MT_view_pie',
            'fallback_operator': 'view3d.view_persportho',
        },
        hotkey_kwargs={'type': 'ACCENT_GRAVE', 'value': 'PRESS'},
        key_cat='3D View',
    )

    # Overload the N key so that if tapped, it toggles the sidebar,
    # which is what most people are used to.
    # But I want people to discover the N pie menu because I think it's great.
    register_hotkey(
        'wm.call_menu_pie_drag_only',
        op_kwargs={
            'name': 'WM_MT_region_toggle_pie',
            'fallback_operator': 'wm.context_toggle',
            'op_kwargs': '{"data_path":"space_data.show_region_ui"}',
        },
        hotkey_kwargs={'type': 'N', 'value': 'PRESS'},
        key_cat='3D View Generic',
    )


def register():
    bpy.app.timers.register(delayed_register, first_interval=0.1)
